       structure /urban/
        real*8 OscStr(2), ExcitErg(2), MacroSigma(3), AveN(3),
     *       ExToIoniz, AveIoniz, Zeff,  Smallc2,
     *       Emax, EmaxI, IEmaxI, EmaxByEmaxI, PreSigma3, 
     *       EmaxN, EmaxIN, IEmaxIN, EmaxByEmaxIN, PreSigma3N, 
     *       ElossByExcit, ElossByIoniz,
     *       Alfa, PAtype, AveIoniz2, SigmaElossA2, AveAtype,
     *       AveElossAtype, SigmaAtype, SigmaByNAtype,
     *       AveElossByNAtype, ElossByAtype, ElossByBtype, ElossTotal,
     *       AveNThin, EOuter
        integer  Ncoll(3), NAtype, NBtype, LargeN3, NThin
       end structure
     	 		
	  
  
     	 		
	  
